==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/SynchronizerManager.h <==
// public class soot.jimple.toolkits.invoke.SynchronizerManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fdc4921d11fa02bf soot_jimple_toolkits_invoke_SynchronizerManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_
#define _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Local$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$addStmtsToFetchClassBefore$1fe957481dd023b3(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$createClassFetcherFor$0b29ffa3b50792da(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$getClassFetcherFor$88ba13a2bf0d9c04(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *);
extern void _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$synchronizeStmtOn$3e6f5811ed7ab76b(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$addStmtsToFetchClassBefore$1fe957481dd023b3;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$createClassFetcherFor$0b29ffa3b50792da;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$getClassFetcherFor$88ba13a2bf0d9c04;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$synchronizeStmtOn$3e6f5811ed7ab76b;

// Static methods
extern struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$v$a0913d4a6c4d6951(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods {
	struct _jc_object	*(*addStmtsToFetchClassBefore$1fe957481dd023b3)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
	struct _jc_soot_SootMethod$object	*(*createClassFetcherFor$0b29ffa3b50792da)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *);
	struct _jc_soot_SootMethod$object	*(*getClassFetcherFor$88ba13a2bf0d9c04)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *);
	void	(*synchronizeStmtOn$3e6f5811ed7ab76b)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods	soot_jimple_toolkits_invoke_SynchronizerManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs {
	struct _jc_java_util_HashMap$object	*classToClassField;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs {
    _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs	soot_jimple_toolkits_invoke_SynchronizerManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs	soot_jimple_toolkits_invoke_SynchronizerManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object {
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype _jc_soot_jimple_toolkits_invoke_SynchronizerManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_SynchronizerManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_SynchronizerManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/SynchronizerManager.h <==
// public class soot.jimple.toolkits.invoke.SynchronizerManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fdc4921d11fa02bf soot_jimple_toolkits_invoke_SynchronizerManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_
#define _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Local$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$addStmtsToFetchClassBefore$1fe957481dd023b3(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$createClassFetcherFor$0b29ffa3b50792da(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$getClassFetcherFor$88ba13a2bf0d9c04(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$synchronizeStmtOn$3e6f5811ed7ab76b(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$addStmtsToFetchClassBefore$1fe957481dd023b3;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$createClassFetcherFor$0b29ffa3b50792da;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$getClassFetcherFor$88ba13a2bf0d9c04;
extern _jc_method _jc_soot_jimple_toolkits_invoke_SynchronizerManager$method_info$synchronizeStmtOn$3e6f5811ed7ab76b;

// Static methods
extern struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *_jc_soot_jimple_toolkits_invoke_SynchronizerManager$method$v$a0913d4a6c4d6951(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods {
	struct _jc_object	*(*addStmtsToFetchClassBefore$1fe957481dd023b3)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*createClassFetcherFor$0b29ffa3b50792da)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getClassFetcherFor$88ba13a2bf0d9c04)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*synchronizeStmtOn$3e6f5811ed7ab76b)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object *, struct _jc_object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vmethods	soot_jimple_toolkits_invoke_SynchronizerManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs {
	struct _jc_java_util_HashMap$object	*classToClassField;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs {
    _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_refs	soot_jimple_toolkits_invoke_SynchronizerManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_SynchronizerManager$sub_nonrefs	soot_jimple_toolkits_invoke_SynchronizerManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_SynchronizerManager$object {
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_SynchronizerManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_SynchronizerManager$vtype _jc_soot_jimple_toolkits_invoke_SynchronizerManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_SynchronizerManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_SynchronizerManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_SynchronizerManager_H_ */
